@@ -34,4 +34,10 @@ CONTINENT_DATA = '{}/v2/continents/{}'
 CONTINENT_YESTERDAY = CONTINENT_DATA + _YESTERDAY_SUFFIX
 
 JHU_CSSE = '{}/v2/jhucsse'
-JHU_CSSE_COUNTIES = '{}/v2/jhucsse/counties/{}'
\ No newline at end of file
+JHU_CSSE_COUNTIES = '{}/v2/jhucsse/counties/{}'
+
+NYT_USA = '{}/v2/nyt/usa'
+NYT_ALL_STATES = '{}/v2/nyt/states'
+NYT_SINGLE_STATE = '{}/v2/nyt/states/{}'
+NYT_ALL_COUNTIES = '{}/v2/nyt/counties'
+NYT_SINGLE_COUNTY = '{}/v2/nyt/counties/{}'
\ No newline at end of file
